@@ -1,8 +1,11 @@
+from __future__ import division
+
 import sys
 import wave
 import numpy as np
 import subprocess as sp
 
+from tqdm import tqdm
 from moviepy.conf import FFMPEG_BINARY
 from moviepy.decorators import requires_duration
 
@@ -54,8 +57,8 @@ class FFMPEG_AudioWriter:
                                  stderr=sp.PIPE)
         
     def write_frames(self,frames_array):
-        #self.proc.stdin.write(img_array.tostring())
-        frames_array.tofile(self.proc.stdin)
+        self.proc.stdin.write(frames_array.tostring())
+        #frames_array.tofile(self.proc.stdin) # only python 2.7
         
     def close(self):
         self.proc.stdin.close()
@@ -79,11 +82,10 @@ def ffmpeg_audiowrite(clip, filename, fps, nbytes, buffersize,
                                 codec=codec, bitrate=bitrate)
                                 
     totalsize = int(fps*clip.duration)
-    nchunks = totalsize / buffersize + 1
+    nchunks = totalsize // buffersize + 1
     pospos = np.array(list(range(0, totalsize,  buffersize))+[totalsize])
-    ifeedback = max(1,nchunks/10)
-    for i in range(nchunks):
-        if ( (i% ifeedback) == 0): verbose_print("=")
+    
+    for i in tqdm(range(nchunks)):
         tt = (1.0/fps)*np.arange(pospos[i],pospos[i+1])
         sndarray = clip.to_soundarray(tt,nbytes)
         writer.write_frames(sndarray)
