@@ -99,7 +99,7 @@ def preview(clip, fps=15, audio=True, audio_fps=22050,
                     
                     if audio:
                         videoFlag.clear()
-                    print "Keyboard interrupt"
+                    print( "Keyboard interrupt" )
                     return result
                     
             elif event.type == pg.MOUSEBUTTONDOWN:
@@ -107,8 +107,8 @@ def preview(clip, fps=15, audio=True, audio_fps=22050,
                 rgb = img[y,x]
                 result.append({'time':t, 'position':(x,y),
                                 'color':rgb})
-                print "time, position, color : ", "%.03f, %s, %s"%(
-                             t,str((x,y)),str(rgb))
+                print( "time, position, color : ", "%.03f, %s, %s"%(
+                             t,str((x,y)),str(rgb)))
                     
         t1 = time.time()
         time.sleep(max(0, t - (t1-t0)) )
@@ -123,14 +123,14 @@ def image_preview(clip):
             if event.type == pg.KEYDOWN:
                 if (event.key == pg.K_ESCAPE):
                     videoFlag.clear()
-                    print "Keyboard interrupt"
+                    print( "Keyboard interrupt" )
                     return result
             elif event.type == pg.MOUSEBUTTONDOWN:
                  x,y = pg.mouse.get_pos()
                  rgb = img[y,x]
                  result.append({'time':t, 'position':(x,y),
                             'color':rgb})
-                 print "time, position, color : ", "%.03f, %s, %s"%(
-                         t,str((x,y)),str(rgb))
+                 print( "time, position, color : ", "%.03f, %s, %s"%(
+                         t,str((x,y)),str(rgb)))
     return result
     
